@@ -22,32 +22,8 @@
  * Corel Corporation or Corel Corporation Limited."
  */
 
-/* libwpd
- * Copyright (C) 2004 Marc Maurer (uwog@uwog.net)
- *  
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
- *
- * You should have received a copy of the GNU Library General Public
- * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
- *
- * For further information visit http://libwpd.sourceforge.net
- */
-
-/* "This product is not manufactured, approved, or supported by 
- * Corel Corporation or Corel Corporation Limited."
- */
-
 #include "WP3EndOfLinePageGroup.h"
-#include "WPXListener.h"
+#include "WP3Listener.h"
 #include "libwpd_internal.h"
 
 WP3EndOfLinePageGroup::WP3EndOfLinePageGroup(WPXInputStream *input) :	
@@ -56,11 +32,6 @@ WP3EndOfLinePageGroup::WP3EndOfLinePageGroup(WPXInputStream *input) :
 	_read(input);
 }
 
-void WP3EndOfLinePageGroup::_readContents(WPXInputStream *input)
-{
-	// nothing really to do here...
-}
-
 void WP3EndOfLinePageGroup::parse(WP3Listener *listener)
 {
 	WPD_DEBUG_MSG(("WordPerfect: handling an End of Line/Page group\n"));
