@@ -1,5 +1,5 @@
 /* libwpd
- * Copyright (C) 2002 William Lachance (william.lachance@sympatico.ca)
+ * Copyright (C) 2002 William Lachance (wrlach@gmail.com)
  * Copyright (C) 2002 Marc Maurer (uwog@uwog.net)
  * Copyright (C) 2004 Fridrich Strba (fridrich.strba@bluewin.ch)
  *
@@ -29,12 +29,14 @@
 #include "WP3FileStructure.h"
 #include "libwpd_internal.h"
 #include "libwpd_math.h"
+#include "WP3Listener.h"
 
 WP3PageFormatGroup::WP3PageFormatGroup(WPXInputStream *input) :
 	WP3VariableLengthGroup(),
 	m_leftMargin(0),
 	m_rightMargin(0),
 	m_lineSpacing(1.0f),
+	m_isRelative(false),
 	m_topMargin(0),
 	m_bottomMargin(0),
 	m_justification(0),
@@ -52,6 +54,10 @@ void WP3PageFormatGroup::_readContents(WPXInputStream *input)
 {
 	// this group can contain different kinds of data, thus we need to read
 	// the contents accordingly
+	int8_t tmpTabType = 0;
+	float tmpTabPosition = 0.0f;
+	WPXTabStop tmpTabStop = WPXTabStop();
+
 	switch (getSubGroup())
 	{
 	case WP3_PAGE_FORMAT_GROUP_HORIZONTAL_MARGINS:
@@ -74,6 +80,88 @@ void WP3PageFormatGroup::_readContents(WPXInputStream *input)
 			m_lineSpacing = lineSpacingIntegerPart + lineSpacingFractionalPart;
 		}
 		break;
+
+	case WP3_PAGE_FORMAT_GROUP_SET_TABS:
+		// skip old condensed tab table if the first value is not 0xFF
+		if (0xFF != readU8(input))
+		{
+			while (readU8(input) != 0xFF)
+				input->seek(4, WPX_SEEK_CUR);
+		}
+
+		m_isRelative = (readU8(input) & 0x01);
+
+		while (((tmpTabType = read8(input)) & 0xff) != 0xff)
+		{
+			if (input->atEOS())
+				throw FileException();
+			tmpTabPosition = fixedPointToFloat(readU32(input, true)) / 72.0f;
+
+			if (tmpTabType < 0)
+			{
+				for (int8_t i = tmpTabType; i < 0; i++)
+				{
+					tmpTabStop.m_position += tmpTabPosition;
+					m_tabStops.push_back(tmpTabStop);
+				}
+			}
+			else
+			{
+				tmpTabStop.m_position = tmpTabPosition;
+
+				switch (tmpTabType & 0x0f)
+				{
+				case 0:
+					tmpTabStop.m_alignment = LEFT;
+					break;
+				case 1:
+					tmpTabStop.m_alignment = CENTER;
+					break;
+				case 2:
+					tmpTabStop.m_alignment = RIGHT;
+					break;
+				case 3:
+					tmpTabStop.m_alignment = DECIMAL;
+					break;
+				case 4: tmpTabStop.m_alignment = BAR;
+					break;
+				default:
+					tmpTabStop.m_alignment = LEFT;
+					break;
+				}
+
+				switch ((tmpTabType & 0x70) >> 4 )
+				{
+				case 0:
+					tmpTabStop.m_leaderCharacter = '\0';
+					tmpTabStop.m_leaderNumSpaces = 0;
+					break;
+				case 1:
+					tmpTabStop.m_leaderCharacter = '.';
+					tmpTabStop.m_leaderNumSpaces = 1;
+					break;
+				case 2:
+					tmpTabStop.m_leaderCharacter = '.';
+					tmpTabStop.m_leaderNumSpaces = 0;
+					break;
+				case 3:
+					tmpTabStop.m_leaderCharacter = '-';
+					tmpTabStop.m_leaderNumSpaces = 1;
+					break;
+				case 4:
+					tmpTabStop.m_leaderCharacter = '_';
+					tmpTabStop.m_leaderNumSpaces = 0;
+					break;
+				default:
+					tmpTabStop.m_leaderCharacter = '.';
+					tmpTabStop.m_leaderNumSpaces = 0;
+					break;
+				}
+
+				m_tabStops.push_back(tmpTabStop);
+			}	
+		}
+		break;
 		
 	case WP3_PAGE_FORMAT_GROUP_VERTICAL_MARGINS:
 		// skip 8 bytes (old values of no interest for us)
@@ -110,6 +198,10 @@ void WP3PageFormatGroup::parse(WP3Listener *listener)
 {
 	WPD_DEBUG_MSG(("WordPerfect: handling a Page Format group\n"));
 
+#ifdef DEBUG
+    std::vector<WPXTabStop>::const_iterator tabStopsIter;
+#endif
+    
 	switch (getSubGroup())
 	{
 	case WP3_PAGE_FORMAT_GROUP_HORIZONTAL_MARGINS:
@@ -132,6 +224,18 @@ void WP3PageFormatGroup::parse(WP3Listener *listener)
 	        listener->lineSpacingChange(m_lineSpacing);
 		break;
 				
+	case WP3_PAGE_FORMAT_GROUP_SET_TABS:
+ #ifdef DEBUG
+		WPD_DEBUG_MSG(("Parsing Set Tabs Group (positions: "));
+        for(tabStopsIter = m_tabStops.begin(); tabStopsIter != m_tabStops.end(); tabStopsIter++)
+		{
+			WPD_DEBUG_MSG((" %.4f", (*tabStopsIter).m_position));
+		}
+		WPD_DEBUG_MSG((")\n"));
+#endif
+		listener->setTabs(m_isRelative, m_tabStops);
+		break;
+
 	case WP3_PAGE_FORMAT_GROUP_VERTICAL_MARGINS:
 		if (m_topMargin != 0x80000000)
 			listener->pageMarginChange(WPX_TOP, fixedPointToWPUs(m_topMargin));
