@@ -1,5 +1,5 @@
 /* libwpd
- * Copyright (C) 2003 William Lachance (william.lachance@sympatico.ca)
+ * Copyright (C) 2003 William Lachance (wrlach@gmail.com)
  * Copyright (C) 2003 Marc Maurer (uwog@uwog.net)
  * Copyright (C) 2006 Fridrich Strba (fridrich.strba@bluewin.ch)
  *  
@@ -40,7 +40,7 @@ WPDConfidence WP42Heuristics::isWP42FileFormat(WPXInputStream *input, bool parti
 	{
 		uint8_t readVal = readU8(input);
 
-		WPD_DEBUG_MSG(("WP42Heuristics, Offset 0x%.8x, value 0x%.2x\n", input->tell() - 1, readVal));
+		WPD_DEBUG_MSG(("WP42Heuristics, Offset 0x%.8x, value 0x%.2x\n", (unsigned int)(input->tell() - 1), readVal));
 		
 		if (readVal < (uint8_t)0x20)
 		{
@@ -55,7 +55,7 @@ WPDConfidence WP42Heuristics::isWP42FileFormat(WPXInputStream *input, bool parti
 			// single character function codes, skip
 			functionGroupCount++;
 		}
-		else if (readVal >= (uint8_t)0xFB)
+		else if (readVal >= (uint8_t)0xFF)
 		{
 			// special codes that should not be found as separate functions
 			return WPD_CONFIDENCE_NONE;
@@ -71,7 +71,7 @@ WPDConfidence WP42Heuristics::isWP42FileFormat(WPXInputStream *input, bool parti
 				// variable length function group
 				
 				// skip over all the bytes in the group, and scan for the closing gate
-				uint8_t readNextVal;
+				uint8_t readNextVal = 0;
 				while (!input->atEOS())
 				{
 					readNextVal = readU8(input);
@@ -80,7 +80,7 @@ WPDConfidence WP42Heuristics::isWP42FileFormat(WPXInputStream *input, bool parti
 				}
 
 				// when passed the complete file, we don't allow for open groups when we've reached EOF
-				if (!partialContent && input->atEOS() && (readNextVal != readVal))
+				if ((readNextVal == 0) || (!partialContent && input->atEOS() && (readNextVal != readVal)))
 					return WPD_CONFIDENCE_NONE;
 				
 				functionGroupCount++;
