@@ -1,5 +1,5 @@
 /* libwpd
- * Copyright (C) 2003 William Lachance (william.lachance@sympatico.ca)
+ * Copyright (C) 2003 William Lachance (wrlach@gmail.com)
  * Copyright (C) 2003 Marc Maurer (uwog@uwog.net)
  * Copyright (C) 2005-2006 Fridrich Strba (fridrich.strba@bluewin.ch)
  *
@@ -33,7 +33,7 @@
 #include "WPXString.h"
 #include "libwpd_internal.h"
 #include "WPXHLListenerImpl.h"
-#include "WPXListener.h"
+#// include "WPXListener.h"
 #include <vector>
 
 typedef struct _WP5ContentParsingState WP5ContentParsingState;
@@ -54,7 +54,7 @@ public:
 	~WP5ContentListener();
 
 	void startDocument() { WPXContentListener::startDocument(); };
-	void setFont(const WPXString fontName, const float fontSize);
+	void setFont(const WPXString &fontName, const float fontSize);
 	void insertCharacter(const uint16_t character);
 	void insertTab(const uint8_t tabType, float tabPosition);
 	void insertEOL();
@@ -63,10 +63,10 @@ public:
 	void justificationChange(const uint8_t justification) { WPXContentListener::justificationChange(justification); };
 	void characterColorChange(const uint8_t red, const uint8_t green, const uint8_t blue);
 	void attributeChange(const bool isOn, const uint8_t attribute);
-	void pageMarginChange(const uint8_t side, const uint16_t margin) {};
-	void pageFormChange(const uint16_t length, const uint16_t width, const WPXFormOrientation orientation, const bool isPersistent) {};
+	void pageMarginChange(const uint8_t /* side */, const uint16_t /* margin */) {};
+	void pageFormChange(const uint16_t /* length */, const uint16_t /* width */, const WPXFormOrientation /* orientation */) {};
 	void marginChange(const uint8_t side, const uint16_t margin);
-	void paragraphMarginChange(const uint8_t side, const int16_t margin) {};
+	void paragraphMarginChange(const uint8_t /* side */, const int16_t /* margin */) {};
 	void endDocument() { WPXContentListener::endDocument(); };
 
 	void defineTable(const uint8_t position, const uint16_t leftOffset);
@@ -80,12 +80,12 @@ public:
 				const bool useCellAttributes, const uint32_t cellAttributes);
  	void endTable();
 
-	void insertNoteReference(const WPXString noteReference);
+	void insertNoteReference(const WPXString &noteReference);
 	void insertNote(const WPXNoteType noteType, const WP5SubDocument *subDocument);
 	void headerFooterGroup(const uint8_t headerFooterType, const uint8_t occurenceBits, WP5SubDocument *subDocument);
-	void suppressPageCharacteristics(const uint8_t suppressCode) {};
+	void suppressPageCharacteristics(const uint8_t /* suppressCode */) {};
 	
-	void setDefaultFont(const WPXString fontName, const float fontSize);
+	void setDefaultFont(const WPXString &fontName, const float fontSize);
 	
 protected:
 	void _handleSubDocument(const WPXSubDocument *subDocument, const bool isHeaderFooter, WPXTableList tableList, int nextTableIndice = 0);
