@@ -1,5 +1,5 @@
 /* libwpd
- * Copyright (C) 2002 William Lachance (william.lachance@sympatico.ca)
+ * Copyright (C) 2002 William Lachance (wrlach@gmail.com)
  * Copyright (C) 2002 Marc Maurer (uwog@uwog.net)
  * Copyright (C) 2004 Fridrich Strba (fridrich.strba@bluewin.ch)
  *
@@ -26,7 +26,7 @@
 
 #include "WP5PageFormatGroup.h"
 #include "WP5FileStructure.h"
-#include "libwpd_internal.h"
+#include "WP5Listener.h"
 
 WP5PageFormatGroup::WP5PageFormatGroup(WPXInputStream *input) :
 	WP5VariableLengthGroup(),
@@ -148,7 +148,7 @@ void WP5PageFormatGroup::parse(WP5Listener *listener)
 		listener->suppressPageCharacteristics(m_suppressCode);
 		break;
 	case WP5_TOP_PAGE_FORMAT_GROUP_FORM:
-		listener->pageFormChange(m_formLength, m_formWidth, m_formOrientation, true);
+		listener->pageFormChange(m_formLength, m_formWidth, m_formOrientation);
 		break;
 	default: // something else we don't support, since it isn't in the docs
 		break;
