@@ -1,5 +1,5 @@
 /* libwpd
- * Copyright (C) 2002-2005 William Lachance (william.lachance@sympatico.ca)
+ * Copyright (C) 2002-2005 William Lachance (wrlach@gmail.com)
  * Copyright (C) 2002 Marc Maurer (uwog@uwog.net)
  * Copyright (C) 2004-2006 Fridrich Strba (fridrich.strba@bluewin.ch)
  *
@@ -43,7 +43,8 @@
 #define WP6_DEFAULT_FONT_SIZE 12.0f
 #define WP6_DEFAULT_FONT_NAME "Times New Roman"
 
-WP6OutlineDefinition::WP6OutlineDefinition(const WP6OutlineLocation outlineLocation, const uint8_t *numberingMethods, const uint8_t tabBehaviourFlag)
+WP6OutlineDefinition::WP6OutlineDefinition(const WP6OutlineLocation outlineLocation, const uint8_t *numberingMethods,
+						const uint8_t /* tabBehaviourFlag */)
 {
 	_updateNumberingMethods(outlineLocation, numberingMethods);
 }
@@ -61,12 +62,12 @@ WP6OutlineDefinition::WP6OutlineDefinition()
 // outline style is defined in a prefix packet, then you are given more information later
 // in the document)
 // FIXME: make sure this is in the right place
-void WP6OutlineDefinition::update(const uint8_t *numberingMethods, const uint8_t tabBehaviourFlag)
+void WP6OutlineDefinition::update(const uint8_t *numberingMethods, const uint8_t /* tabBehaviourFlag */)
 {
 	_updateNumberingMethods(paragraphGroup, numberingMethods);
 }
 
-void WP6OutlineDefinition::_updateNumberingMethods(const WP6OutlineLocation outlineLocation, const uint8_t *numberingMethods)
+void WP6OutlineDefinition::_updateNumberingMethods(const WP6OutlineLocation /* outlineLocation */, const uint8_t *numberingMethods)
 {
 	for (int i=0; i<WP6_NUM_LIST_LEVELS; i++)
 	{
@@ -109,7 +110,7 @@ _WP6ContentParsingState::_WP6ContentParsingState(WPXTableList tableList, int nex
 	m_isListReference(false),
 
 	m_tableList(tableList),
-	m_currentTable(NULL),
+	m_currentTable(0),
 
 	m_nextTableIndice(nextTableIndice),
 
@@ -119,6 +120,7 @@ _WP6ContentParsingState::_WP6ContentParsingState(WPXTableList tableList, int nex
 	m_putativeListElementHasDisplayReferenceNumber(false),
 	
 	m_noteTextPID(0),
+	m_numNestedNotes(0),
 
 	m_leaderCharacter('.'),
 	m_leaderNumSpaces(0)
@@ -315,11 +317,11 @@ void WP6ContentListener::insertTab(const uint8_t tabType, float tabPosition)
 			// Begin of code to be removed when the TabGroup is properly implemented
 			case WP6_TAB_GROUP_CENTER_ON_MARGINS:
 			case WP6_TAB_GROUP_CENTER_ON_CURRENT_POSITION:
-				m_ps->m_tempParagraphJustification = WP6_PARAGRAPH_JUSTIFICATION_CENTER;
+				m_ps->m_tempParagraphJustification = WPX_PARAGRAPH_JUSTIFICATION_CENTER;
 				break;
 
 			case WP6_TAB_GROUP_FLUSH_RIGHT:
-				m_ps->m_tempParagraphJustification = WP6_PARAGRAPH_JUSTIFICATION_RIGHT;
+				m_ps->m_tempParagraphJustification = WPX_PARAGRAPH_JUSTIFICATION_RIGHT;
 				break;
 			// End of code to be removed when the TabGroup is properly implemented
 
@@ -501,7 +503,7 @@ void WP6ContentListener::fontChange(const uint16_t matchedFontPointSize, const u
 		_closeSpan();
 		if (matchedFontPointSize)
 		{
-			m_ps->m_fontSize = rint((double)((((float)matchedFontPointSize)/100.0f)*2.0f));
+			m_ps->m_fontSize = (float)rint((double)((((double)matchedFontPointSize)/100.0f)*2.0f));
 			// We compute the real space after paragraph in inches using the size of the font and relative spacing.
 			// We have to recompute this every change of fontSize.
 			m_ps->m_paragraphMarginBottom =
@@ -510,9 +512,10 @@ void WP6ContentListener::fontChange(const uint16_t matchedFontPointSize, const u
 		}
 		if (fontPID)
 		{
-			const WP6FontDescriptorPacket *fontDescriptorPacket = NULL;
-			if (fontDescriptorPacket = dynamic_cast<const WP6FontDescriptorPacket *>(WP6Listener::getPrefixDataPacket(fontPID))) {
-				m_ps->m_fontName->sprintf("%s", fontDescriptorPacket->getFontName());
+			const WP6FontDescriptorPacket *fontDescriptorPacket = 
+				dynamic_cast<const WP6FontDescriptorPacket *>(WP6Listener::getPrefixDataPacket(fontPID));
+			if (fontDescriptorPacket) {
+				*(m_ps->m_fontName) = fontDescriptorPacket->getFontName();
 			}
 		}
 	}
@@ -709,14 +712,12 @@ void WP6ContentListener::indentFirstLineChange(int16_t offset)
 	}
 }
 
-void WP6ContentListener::columnChange(const WPXTextColumnType columnType, const uint8_t numColumns, const std::vector<float> &columnWidth,
-		const std::vector<bool> &isFixedWidth)
+void WP6ContentListener::columnChange(const WPXTextColumnType /* columnType */, const uint8_t numColumns,
+					const std::vector<float> &columnWidth, const std::vector<bool> &isFixedWidth)
 {
 	if (!isUndoOn())
 	{
 		int oldColumnNum = m_ps->m_numColumns;
-		if (oldColumnNum > 1)
-			m_ps->m_paragraphJustification = m_ps->m_paragraphJustificationBeforeColumns;
 
 		// In WP, the last column ends with a hard column break code.
 		// In this case, we do not really want to insert any column break
@@ -732,7 +733,7 @@ void WP6ContentListener::columnChange(const WPXTextColumnType columnType, const
 		if (numColumns > 1)
 		{
 			int i;
-			for (i=0; i<columnWidth.size(); i++)
+			for (i=0; i<(int)columnWidth.size(); i++)
 			{
 				if (isFixedWidth[i])
 					remainingSpace -= columnWidth[i];
@@ -781,8 +782,6 @@ void WP6ContentListener::columnChange(const WPXTextColumnType columnType, const
 			m_ps->m_paragraphMarginLeft += m_ps->m_leftMarginByPageMarginChange;
 			m_ps->m_paragraphMarginRight += m_ps->m_rightMarginByPageMarginChange;
 		}
-		if (m_ps->m_numColumns > 1)
-			m_ps->m_paragraphJustificationBeforeColumns = m_ps->m_paragraphJustification;
 	}
 }
 
@@ -804,7 +803,7 @@ void WP6ContentListener::updateOutlineDefinition(const WP6OutlineLocation outlin
 	}
 }
 
-void WP6ContentListener::paragraphNumberOn(const uint16_t outlineHash, const uint8_t level, const uint8_t flag)
+void WP6ContentListener::paragraphNumberOn(const uint16_t outlineHash, const uint8_t level, const uint8_t /* flag */)
 {
 	if (!isUndoOn())
 	{
@@ -826,7 +825,7 @@ void WP6ContentListener::paragraphNumberOff()
 	}
 }
 
-void WP6ContentListener::displayNumberReferenceGroupOn(const uint8_t subGroup, const uint8_t level)
+void WP6ContentListener::displayNumberReferenceGroupOn(const uint8_t subGroup, const uint8_t /* level */)
 {
 	if (!isUndoOn())
 	{
@@ -965,6 +964,12 @@ void WP6ContentListener::noteOn(const uint16_t textPID)
 {
 	if (!isUndoOn())
 	{
+		if (m_ps->m_isNote)
+		{
+			m_parseState->m_numNestedNotes++;
+			return;
+		}
+
 		_closeSpan();
 		m_parseState->m_styleStateSequence.setCurrentState(DOCUMENT_NOTE);
 		// save a reference to the text PID, we want to parse
@@ -978,21 +983,28 @@ void WP6ContentListener::noteOff(const WPXNoteType noteType)
 {
 	if (!isUndoOn())
 	{
+		if (m_parseState->m_numNestedNotes > 0)
+		{
+			m_parseState->m_numNestedNotes--;
+			return;
+		}
+
 		m_parseState->m_styleStateSequence.setCurrentState(NORMAL);
 		WPXNumberingType numberingType = _extractWPXNumberingTypeFromBuf(m_parseState->m_numberText, ARABIC);
 		int number = _extractDisplayReferenceNumberFromBuf(m_parseState->m_numberText, numberingType);
 		m_parseState->m_numberText.clear(); // we do not need the text version of the number anymore
 
 		WPXPropertyList propList;
-		propList.insert("libwpd:number", number);
+		if (number)
+			propList.insert("libwpd:number", number);
 
 		if (noteType == FOOTNOTE)
 			m_listenerImpl->openFootnote(propList);
 		else
 			m_listenerImpl->openEndnote(propList);
 
-		uint16_t textPID = m_parseState->m_noteTextPID;
-		handleSubDocument(((textPID && WP6Listener::getPrefixDataPacket(textPID)) ? WP6Listener::getPrefixDataPacket(textPID)->getSubDocument() : NULL), 
+		uint16_t textPID = (uint16_t)m_parseState->m_noteTextPID;
+		handleSubDocument(((textPID && WP6Listener::getPrefixDataPacket(textPID)) ? WP6Listener::getPrefixDataPacket(textPID)->getSubDocument() : 0), 
 				false, m_parseState->m_tableList, m_parseState->m_nextTableIndice);
 
 		if (noteType == FOOTNOTE)
@@ -1000,6 +1012,7 @@ void WP6ContentListener::noteOff(const WPXNoteType noteType)
 		else
 			m_listenerImpl->closeEndnote();
 		m_ps->m_isNote = false;
+		m_parseState->m_numNestedNotes = 0;
 	}
 }
 
@@ -1051,8 +1064,8 @@ void WP6ContentListener::defineTable(const uint8_t position, const uint16_t left
 	}
 }
 
-void WP6ContentListener::addTableColumnDefinition(const uint32_t width, const uint32_t leftGutter, const uint32_t rightGutter,
-												  const uint32_t attributes, const uint8_t alignment)
+void WP6ContentListener::addTableColumnDefinition(const uint32_t width, const uint32_t /* leftGutter */,
+						const uint32_t /* rightGutter */, const uint32_t attributes, const uint8_t alignment)
 {
 	if (!isUndoOn())
 	{
@@ -1100,7 +1113,7 @@ void WP6ContentListener::startTable()
 
 void WP6ContentListener::insertRow(const uint16_t rowHeight, const bool isMinimumHeight, const bool isHeaderRow)
 {
-	if (!isUndoOn())
+	if (!isUndoOn() && m_ps->m_isTableOpened)
 	{
 		_flushText();
 		float rowHeightInch = (float)((double) rowHeight / (double)WPX_NUM_WPUS_PER_INCH);
@@ -1108,12 +1121,12 @@ void WP6ContentListener::insertRow(const uint16_t rowHeight, const bool isMinimu
 	}
 }
 
-void WP6ContentListener::insertCell(const uint8_t colSpan, const uint8_t rowSpan, const uint8_t borderBits, 
+void WP6ContentListener::insertCell(const uint8_t colSpan, const uint8_t rowSpan, const uint8_t /* borderBits */, 
 					const RGBSColor * cellFgColor, const RGBSColor * cellBgColor, 
 					const RGBSColor * cellBorderColor, const WPXVerticalAlignment cellVerticalAlignment, 
 					const bool useCellAttributes, const uint32_t cellAttributes)
 {
-	if (!isUndoOn())
+	if (!isUndoOn() && m_ps->m_isTableOpened)
 	{
 		if (m_ps->m_currentTableRow < 0) // cell without a row, invalid
 		{
@@ -1127,15 +1140,15 @@ void WP6ContentListener::insertCell(const uint8_t colSpan, const uint8_t rowSpan
 			throw ParseException(); // no table opened, invalid
 		}
 			
-		if (m_parseState->m_currentTable->getRows().size() <= m_ps->m_currentTableRow)
+		if ((int)m_parseState->m_currentTable->getRows().size() <= (int)m_ps->m_currentTableRow)
 		{
 			WPD_DEBUG_MSG(("Requesting a row larger than the number of rows the table holds\n"));
 			throw ParseException(); // requesting a row larger than the number of rows the table holds
 		}
 			
-		if (m_parseState->m_currentTable->getRows()[m_ps->m_currentTableRow]->size() <= m_ps->m_currentTableCellNumberInRow)
+		if ((int)m_parseState->m_currentTable->getRows()[m_ps->m_currentTableRow].size() <= (int)m_ps->m_currentTableCellNumberInRow)
 		{
-			WPD_DEBUG_MSG(("Requesting a cell smallar than the number of cells in the row\n"));
+			WPD_DEBUG_MSG(("Requesting a cell smaller than the number of cells in the row\n"));
 			throw ParseException(); // requesting a cell smaller than the number of cells in the row
 		}
 			
@@ -1171,6 +1184,7 @@ void WP6ContentListener::_handleSubDocument(const WPXSubDocument *subDocument, c
 	WP6ContentParsingState *oldParseState = m_parseState;
 	
 	m_parseState = new WP6ContentParsingState(tableList, nextTableIndice);
+	m_parseState->m_numNestedNotes = oldParseState->m_numNestedNotes;
 
 	if (isHeaderFooter)
 	{
@@ -1201,6 +1215,7 @@ void WP6ContentListener::_handleSubDocument(const WPXSubDocument *subDocument, c
 	// if we are in a foot/endNote, the nextTableIndice sequence has to be maintained
 	if (!isHeaderFooter)
 		oldParseState->m_nextTableIndice = m_parseState->m_nextTableIndice;
+	oldParseState->m_numNestedNotes = m_parseState->m_numNestedNotes;
 
 	// restore our old parsing state
 	delete m_parseState;
@@ -1263,7 +1278,7 @@ void WP6ContentListener::_flushText()
 	
 	if (m_parseState->m_numListExtraTabs > 0)
 	{
-		for (m_parseState->m_numListExtraTabs; m_parseState->m_numListExtraTabs > 0; m_parseState->m_numListExtraTabs--)
+		for (; m_parseState->m_numListExtraTabs > 0; m_parseState->m_numListExtraTabs--)
 			m_listenerImpl->insertTab();
 		m_parseState->m_numListExtraTabs = 0;
 	}
@@ -1394,7 +1409,7 @@ void WP6ContentListener::_changeList()
 	_handleListChange(m_parseState->m_currentOutlineHash);
 }
 
-void WP6ContentListener::undoChange(const uint8_t undoType, const uint16_t undoLevel)
+void WP6ContentListener::undoChange(const uint8_t undoType, const uint16_t /* undoLevel */)
 {
 	if (undoType == WP6_UNDO_GROUP_INVALID_TEXT_START)
 		setUndoOn(true);
