@@ -1,6 +1,6 @@
 /* libwpd
- * Copyright (C) 2002 William Lachance (william.lachance@sympatico.ca)
- * Copyright (C) 2002 Marc Maurer (j.m.maurer@student.utwente.nl)
+ * Copyright (C) 2002 William Lachance (wrlach@gmail.com)
+ * Copyright (C) 2002 Marc Maurer (uwog@uwog.net)
  *  
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public
@@ -14,7 +14,7 @@
  *
  * You should have received a copy of the GNU Library General Public
  * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
  *
  * For further information visit http://libwpd.sourceforge.net
  */
@@ -23,26 +23,26 @@
  * Corel Corporation or Corel Corporation Limited."
  */
 
-#include "WP6HLListener.h"
+#include "WP6Listener.h"
 #include "WP6DefaultInitialFontPacket.h"
 #include "libwpd_internal.h"
 
-WP6DefaultInitialFontPacket::WP6DefaultInitialFontPacket(GsfInput *input, int id, guint32 dataOffset, guint32 dataSize)
+WP6DefaultInitialFontPacket::WP6DefaultInitialFontPacket(WPXInputStream *input, int /* id */, uint32_t dataOffset, uint32_t dataSize)
 	: WP6PrefixDataPacket(input)
 {
 	_read(input, dataOffset, dataSize);
 }
 
-void WP6DefaultInitialFontPacket::parse(WP6HLListener *listener) const
+void WP6DefaultInitialFontPacket::parse(WP6Listener *listener) const
 {
 	listener->fontChange(getPointSize(), getInitialFontDescriptorPID());
 }
 
-void WP6DefaultInitialFontPacket::_readContents(GsfInput *input)
+void WP6DefaultInitialFontPacket::_readContents(WPXInputStream *input)
 {
-   m_numPrefixIDs = gsf_le_read_guint16(input);
-   m_initialFontDescriptorPID = gsf_le_read_guint16(input);
-   m_pointSize = gsf_le_read_guint16(input);
+   m_numPrefixIDs = readU16(input);
+   m_initialFontDescriptorPID = readU16(input);
+   m_pointSize = readU16(input);
    WPD_DEBUG_MSG(("WordPerfect: Read default initial font packet (initial font descriptor pid: %i, point size: %i)\n", 
 		  (int) m_initialFontDescriptorPID, (int) m_pointSize));
 }
