@@ -1,5 +1,5 @@
 /* libwpd
- * Copyright (C) 2002 William Lachance (william.lachance@sympatico.ca)
+ * Copyright (C) 2002 William Lachance (wrlach@gmail.com)
  * Copyright (C) 2002 Marc Maurer (uwog@uwog.net)
  * Copyright (C) 2006 Fridrich Strba (fridrich.strba@bluewin.ch)
  *  
@@ -24,14 +24,15 @@
  * Corel Corporation or Corel Corporation Limited."
  */
 #include <string.h>
+#include <limits>
 
 #include "WP6ExtendedDocumentSummaryPacket.h"
 #include "libwpd_internal.h"
 
-WP6ExtendedDocumentSummaryPacket::WP6ExtendedDocumentSummaryPacket(WPXInputStream *input, int id, uint32_t dataOffset, uint32_t dataSize) :
+WP6ExtendedDocumentSummaryPacket::WP6ExtendedDocumentSummaryPacket(WPXInputStream *input, int /* id */, uint32_t dataOffset, uint32_t dataSize) :
 	WP6PrefixDataPacket(input),
 	m_dataSize(dataSize),
-	m_stream(NULL)
+	m_stream(0)
 {	
 	if (dataSize > 0)
 		_read(input, dataOffset, dataSize);
@@ -47,11 +48,13 @@ void WP6ExtendedDocumentSummaryPacket::_readContents(WPXInputStream *input)
 {
 	if (m_dataSize <= 0)
 		return;
+	if (m_dataSize > ((std::numeric_limits<uint32_t>::max)() / 2))
+		m_dataSize = ((std::numeric_limits<uint32_t>::max)() / 2);
 	uint8_t *streamData = new uint8_t[m_dataSize];
-	for(int i=0; i<m_dataSize; i++)
+	for(unsigned i=0; i<(unsigned)m_dataSize; i++)
 		streamData[i] = readU8(input);
 	
-	m_stream = new WPXMemoryInputStream(streamData, m_dataSize);
+	m_stream = new WPXMemoryInputStream(streamData, (size_t)m_dataSize);
 }
 
 void WP6ExtendedDocumentSummaryPacket::parse(WP6Listener *listener) const
@@ -60,7 +63,7 @@ void WP6ExtendedDocumentSummaryPacket::parse(WP6Listener *listener) const
 		return;
 	uint16_t groupLength = 0;
 
-	for (int i=0; i < m_dataSize && !m_stream->atEOS(); i+=groupLength)
+	for (unsigned i=0; i < (unsigned)m_dataSize && !m_stream->atEOS(); i+=groupLength)
 	{
 		groupLength = readU16(m_stream);
 		if ((groupLength <= 0) || m_stream->atEOS())
@@ -72,16 +75,15 @@ void WP6ExtendedDocumentSummaryPacket::parse(WP6Listener *listener) const
 			return;
 
 		WPXString name;
-		uint16_t wpChar;
+		uint16_t wpChar = 0;
 		if (!m_stream->atEOS())
 			wpChar = readU16(m_stream);
 		for (; wpChar != 0 && !m_stream->atEOS(); wpChar = readU16(m_stream))
 		{
-			uint8_t character = (wpChar & 0xFF);
-			uint8_t characterSet = (wpChar & 0xFF00) >> 8;
+			uint8_t character = (uint8_t)(wpChar & 0x00FF);
+			uint8_t characterSet = (uint8_t)((wpChar >> 8) & 0x00FF);
 			const uint16_t *chars;
-			int len;
-			len = extendedCharacterWP6ToUCS2(character,
+			int len = extendedCharacterWP6ToUCS2(character,
 						      characterSet, &chars);
 			for (int j = 0; j < len; j++)
 				appendUCS4(name, (uint32_t)chars[j]);
@@ -108,11 +110,10 @@ void WP6ExtendedDocumentSummaryPacket::parse(WP6Listener *listener) const
 				wpChar = readU16(m_stream);
 			for (; wpChar != 0 && !m_stream->atEOS(); wpChar = readU16(m_stream))
 			{				
-				uint8_t character = (wpChar & 0xFF);
-				uint8_t characterSet = (wpChar & 0xFF00) >> 8;
+				uint8_t character = (uint8_t)(wpChar & 0x00FF);
+				uint8_t characterSet = (uint8_t)((wpChar >> 8) & 0x00FF);
 				const uint16_t *chars;
-				int len;
-				len = extendedCharacterWP6ToUCS2(character,
+				int len = extendedCharacterWP6ToUCS2(character,
 						      characterSet, &chars);
 				for (int j = 0; j < len; j++)
 					appendUCS4(data, (uint32_t)chars[j]);
