@@ -1,5 +1,5 @@
 /* libwpd
- * Copyright (C) 2002 William Lachance (william.lachance@sympatico.ca)
+ * Copyright (C) 2002 William Lachance (wrlach@gmail.com)
  * Copyright (C) 2002 Marc Maurer (uwog@uwog.net)
  *  
  * This library is free software; you can redistribute it and/or
@@ -23,7 +23,7 @@
  * Corel Corporation or Corel Corporation Limited."
  */
 #include <string.h>
-
+#include <limits>
 #include "WP6FontDescriptorPacket.h"
 #include "libwpd_internal.h"
 
@@ -34,7 +34,7 @@ const char *FONT_WEIGHT_STRINGS[] = {	"Bold", "bold", "Demi", "demi", "Extended"
 const char * USELESS_WP_POSTFIX = "-WP";
 #define countElements(a) ((sizeof(a) / sizeof(a[0])))
 
-WP6FontDescriptorPacket::WP6FontDescriptorPacket(WPXInputStream *input, int id, uint32_t dataOffset, uint32_t dataSize) 
+WP6FontDescriptorPacket::WP6FontDescriptorPacket(WPXInputStream *input, int /* id */, uint32_t dataOffset, uint32_t dataSize) 
 	: WP6PrefixDataPacket(input)
 {
 	_read(input, dataOffset, dataSize);
@@ -69,9 +69,9 @@ void WP6FontDescriptorPacket::_readContents(WPXInputStream *input)
 
    m_fontNameLength = readU16(input); 
 
-   // TODO: re-do sanity checking
-   //if(m_fontNameLength < WP_FONT_NAME_MAX_LENGTH)
-   //{	
+
+   if (m_fontNameLength > ((std::numeric_limits<uint16_t>::max)() / 2))
+	m_fontNameLength = ((std::numeric_limits<uint16_t>::max)() / 2);
    if (m_fontNameLength == 0) 
 	   {
 		   m_fontName = new char[1];
@@ -87,16 +87,13 @@ void WP6FontDescriptorPacket::_readContents(WPXInputStream *input)
 		   int lastTokenPosition=0;
 		   for (uint16_t i=0; i<(m_fontNameLength/2); i++) 
 		   {
-			   uint8_t characterSet;
-			   uint8_t character;
-			   int len;
-			   const uint16_t *chars;
 			   uint16_t charWord = readU16(input);
 
-			   characterSet = (charWord & 0xFF00) >> 8;
-			   character = (charWord & 0xFF);
+			   uint8_t characterSet = (uint8_t)((charWord >> 8) & 0x00FF);
+			   uint8_t character = (uint8_t)(charWord & 0xFF);
 			   
-			   len = extendedCharacterWP6ToUCS2(character, characterSet, &chars);
+			   const uint16_t *chars;
+			   extendedCharacterWP6ToUCS2(character, characterSet, &chars);
 			   /* We are only using ascii characters here, and
 			    * if we have more than one character, that's
 			    * going to be an international character, so
@@ -130,7 +127,7 @@ void WP6FontDescriptorPacket::_readContents(WPXInputStream *input)
 				   if (stringPosition > 0 && !strcmp(FONT_WEIGHT_STRINGS[k], &m_fontName[stringPosition])) 
 				   {
 					   m_fontName[stringPosition-1]='\0';
-					   tempLength = stringPosition-1;
+					   tempLength = (uint16_t)(stringPosition-1);
 					   break;
 				   }
 			   }
@@ -141,7 +138,7 @@ void WP6FontDescriptorPacket::_readContents(WPXInputStream *input)
 				   if (!strcmp(USELESS_WP_POSTFIX, &m_fontName[stringPosition])) 
 				   {
 					   m_fontName[stringPosition]='\0';
-					   tempLength = stringPosition - 1;
+					   tempLength = (uint16_t)(stringPosition - 1);
 				   }
 			   }
 			   // also consume any whitespace at the end of the font..
