@@ -1,5 +1,5 @@
 /* libwpd
- * Copyright (C) 2002 William Lachance (william.lachance@sympatico.ca)
+ * Copyright (C) 2002 William Lachance (wrlach@gmail.com)
  * Copyright (C) 2002 Marc Maurer (uwog@uwog.net)
  *  
  * This library is free software; you can redistribute it and/or
@@ -24,6 +24,8 @@
  */
 
 #include "WP6FootnoteEndnoteGroup.h"
+#include "WP6FileStructure.h"
+#include "WP6Listener.h"
 #include "libwpd_internal.h"
 
 WP6FootnoteEndnoteGroup::WP6FootnoteEndnoteGroup(WPXInputStream *input) :
@@ -32,7 +34,7 @@ WP6FootnoteEndnoteGroup::WP6FootnoteEndnoteGroup(WPXInputStream *input) :
 	_read(input);
 }
 
-void WP6FootnoteEndnoteGroup::_readContents(WPXInputStream *input)
+void WP6FootnoteEndnoteGroup::_readContents(WPXInputStream * /* input */)
 {
 }
 
