@@ -1,5 +1,5 @@
 /* libwpd
- * Copyright (C) 2002 William Lachance (william.lachance@sympatico.ca)
+ * Copyright (C) 2002 William Lachance (wrlach@gmail.com)
  * Copyright (C) 2002 Marc Maurer (uwog@uwog.net)
  *  
  * This library is free software; you can redistribute it and/or
@@ -27,7 +27,7 @@
 #include "WP6OutlineStylePacket.h"
 #include "libwpd_internal.h"
 
-WP6OutlineStylePacket::WP6OutlineStylePacket(WPXInputStream *input, int id, uint32_t dataOffset, uint32_t dataSize) 
+WP6OutlineStylePacket::WP6OutlineStylePacket(WPXInputStream *input, int /* id */, uint32_t dataOffset, uint32_t dataSize) 
 	: WP6PrefixDataPacket(input)
 {
 	_read(input, dataOffset, dataSize);
@@ -39,7 +39,7 @@ WP6OutlineStylePacket::~WP6OutlineStylePacket()
 
 void WP6OutlineStylePacket::_readContents(WPXInputStream *input)
 {
-	unsigned int i;
+	unsigned i;
 
 	m_numPIDs = readU16(input);
 	for (i=0; i<WP6_NUM_LIST_LEVELS; i++) 
