@@ -1,5 +1,5 @@
 /* libwpd
- * Copyright (C) 2002 William Lachance (william.lachance@sympatico.ca)
+ * Copyright (C) 2002 William Lachance (wrlach@gmail.com)
  * Copyright (C) 2002 Marc Maurer (uwog@uwog.net)
  * Copyright (C) 2004 Fridrich Strba (fridrich.strba@bluewin.ch)
  *  
@@ -25,9 +25,11 @@
  */
 
 #include "WP6SingleByteFunction.h"
+#include "WP6FileStructure.h"
+#include "WP6Listener.h"
 #include "libwpd_internal.h"
 
-WP6SingleByteFunction * WP6SingleByteFunction::constructSingleByteFunction(WPXInputStream *input, uint8_t groupID)
+WP6SingleByteFunction * WP6SingleByteFunction::constructSingleByteFunction(WPXInputStream * /* input */, uint8_t groupID)
 {
 
 	switch (groupID) 
@@ -80,7 +82,7 @@ WP6SingleByteFunction * WP6SingleByteFunction::constructSingleByteFunction(WPXIn
 //		case WP6_TOP_AUTO_HYPHEN:
 		default:
 			// should not happen
-			return NULL;
+			return 0;
 		}
 		
 		// search for soft page breaks and dispatch messages to that effect
@@ -152,14 +154,14 @@ void WP6TableRowFunction::parse(WP6Listener *listener)
 	// would use the multi-byte variant of this function
 	listener->insertRow(0x0000, true, false);
 	RGBSColor tmpCellBorderColor(0x00, 0x00, 0x00, 0x64);
-	listener->insertCell(1, 1, 0x00, NULL, NULL, &tmpCellBorderColor, TOP, false, 0x00000000);
+	listener->insertCell(1, 1, 0x00, 0, 0, &tmpCellBorderColor, TOP, false, 0x00000000);
 }
 
 void WP6TableCellFunction::parse(WP6Listener *listener)
 {
 	// default values
 	RGBSColor tmpCellBorderColor(0x00, 0x00, 0x00, 0x64);
-	listener->insertCell(1, 1, 0x00, NULL, NULL, &tmpCellBorderColor, TOP, false, 0x00000000);
+	listener->insertCell(1, 1, 0x00, 0, 0, &tmpCellBorderColor, TOP, false, 0x00000000);
 }
 
 void WP6TableOffFunction::parse(WP6Listener *listener)
