@@ -1,6 +1,6 @@
 /* libwpd
- * Copyright (C) 2002 William Lachance (william.lachance@sympatico.ca)
- * Copyright (C) 2002 Marc Maurer (j.m.maurer@student.utwente.nl)
+ * Copyright (C) 2002 William Lachance (wrlach@gmail.com)
+ * Copyright (C) 2002 Marc Maurer (uwog@uwog.net)
  *  
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -14,7 +14,7 @@
  *
  * You should have received a copy of the GNU Library General Public
  * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
  *
  * For further information visit http://libwpd.sourceforge.net
  */
@@ -31,49 +31,73 @@
 class WP6SingleByteFunction : public WP6Part
 {
  public:
-	static WP6SingleByteFunction * WP6SingleByteFunction::constructSingleByteFunction(GsfInput *input, guint8 groupID);
+	static WP6SingleByteFunction * constructSingleByteFunction(WPXInputStream *input, uint8_t groupID);
 };
 
 class WP6SpaceFunction : public WP6SingleByteFunction
 {
 public:
-	virtual void parse(WP6HLListener *listener);	
+	void parse(WP6Listener *listener);	
 };
 
 class WP6HardSpaceFunction : public WP6SingleByteFunction
 {
 public:
-	virtual void parse(WP6HLListener *listener);	
+	void parse(WP6Listener *listener);	
 };
 
 class WP6EOLFunction : public WP6SingleByteFunction
 {
 public:
-	virtual void parse(WP6HLListener *listener);	
+	void parse(WP6Listener *listener);	
 };
 
 class WP6EOCFunction : public WP6SingleByteFunction
 {
 public:
-	virtual void parse(WP6HLListener *listener);	
+	void parse(WP6Listener *listener);	
 };
 
 class WP6EOPFunction : public WP6SingleByteFunction
 {
 public:
-	virtual void parse(WP6HLListener *listener);	
+	void parse(WP6Listener *listener);	
+};
+
+class WP6SoftEOPFunction : public WP6SingleByteFunction
+{
+public:
+	void parse(WP6Listener *listener);	
 };
 
 class WP6SoftHyphenFunction : public WP6SingleByteFunction
 {
 public:
-	virtual void parse(WP6HLListener *listener);	
+	void parse(WP6Listener *listener);	
 };
 
 class WP6HyphenFunction : public WP6SingleByteFunction
 {
 public:
-	virtual void parse(WP6HLListener *listener);	
+	void parse(WP6Listener *listener);	
+};
+
+class WP6TableOffFunction : public WP6SingleByteFunction
+{
+public:
+	void parse(WP6Listener *listener);	
+};
+
+class WP6TableCellFunction : public WP6SingleByteFunction
+{
+public:
+	void parse(WP6Listener *listener);	
+};
+
+class WP6TableRowFunction : public WP6SingleByteFunction
+{
+public:
+	void parse(WP6Listener *listener);	
 };
 
 #endif /* WP6SINGLEBYTEFUNCTION_H */
