@@ -33,13 +33,15 @@ class WPXSubDocument
 {
 public:
 	WPXSubDocument();
-	WPXSubDocument(WPXInputStream *input, const int dataSize);
-	WPXSubDocument(uint8_t * streamData, const int dataSize);
+	WPXSubDocument(WPXInputStream *input, const unsigned dataSize);
+	WPXSubDocument(uint8_t * streamData, const unsigned dataSize);
 	virtual ~WPXSubDocument();
 	WPXMemoryInputStream *getStream() const { return m_stream;}
 
 private:              
 	WPXMemoryInputStream *m_stream;
+	WPXSubDocument(const WPXSubDocument&);
+	WPXSubDocument& operator=(const WPXSubDocument&);
 	
 };
-#endif /* WP3SUBDOCUMENT_H */
+#endif /* WPXSUBDOCUMENT_H */
