@@ -1,6 +1,6 @@
 /* libwpd
- * Copyright (C) 2002 William Lachance (william.lachance@sympatico.ca)
- * Copyright (C) 2002 Marc Maurer (j.m.maurer@student.utwente.nl)
+ * Copyright (C) 2002 William Lachance (wrlach@gmail.com)
+ * Copyright (C) 2002 Marc Maurer (uwog@uwog.net)
  *  
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public
@@ -14,7 +14,7 @@
  *
  * You should have received a copy of the GNU Library General Public
  * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
  *
  * For further information visit http://libwpd.sourceforge.net
  */
@@ -35,50 +35,56 @@
 #ifndef _WPXTABLE_H
 #define _WPXTABLE_H
 #include <vector>
-#include <glib.h>
-
-using namespace std;
+#include "libwpd_types.h"
 
 typedef struct _WPXTableCell WPXTableCell;
 
 struct _WPXTableCell
 {
-	_WPXTableCell(guint8 colSpan, guint8 rowSpan, bool boundFromLeft, bool boundFromAbove, guint8 borderBits);
-	guint8 m_colSpan;
-	guint8 m_rowSpan;
-	bool m_boundFromLeft, m_boundFromAbove;
-	guint8 m_borderBits;
+	_WPXTableCell(uint8_t colSpan, uint8_t rowSpan, uint8_t borderBits);
+	uint8_t m_colSpan;
+	uint8_t m_rowSpan;
+	uint8_t m_borderBits;
 };
 
 class WPXTable
 {
 public:
+	WPXTable() {}
 	~WPXTable();
 	void insertRow();
-	void insertCell(guint8 colSpan, guint8 rowSpan, bool boundFromLeft, bool boundFromAbove, guint8 borderBits);
-	const WPXTableCell * getCell(int i, int j) { return (*m_tableRows[i])[j]; }
+	void insertCell(uint8_t colSpan, uint8_t rowSpan, uint8_t borderBits);
+	const WPXTableCell*  getCell(int i, int j) { return (m_tableRows[i])[j]; }
 	void makeBordersConsistent();
-	void _makeCellBordersConsistent(WPXTableCell *cell, vector<WPXTableCell *> *adjacentCells, 
+	void _makeCellBordersConsistent(WPXTableCell *cell, std::vector<WPXTableCell *> &adjacentCells, 
 				      int adjacencyBitCell, int adjacencyBitBoundCells);
-	vector<WPXTableCell *> * _getCellsBottomAdjacent(int i, int j);
-	vector<WPXTableCell *> * _getCellsRightAdjacent(int i, int j);
+	std::vector<WPXTableCell *>  _getCellsBottomAdjacent(int i, int j);
+	std::vector<WPXTableCell *>  _getCellsRightAdjacent(int i, int j);
+
+	const std::vector< std::vector<WPXTableCell *> >& getRows() const { return m_tableRows; }
+
 private:
-	vector< vector<WPXTableCell *> * > m_tableRows;
+	std::vector< std::vector<WPXTableCell *> > m_tableRows;
 };
 
 class WPXTableList
 {
 public:
 	WPXTableList();
+	WPXTableList(const WPXTableList &);
+	WPXTableList & operator=(const WPXTableList & tableList);
 	virtual ~WPXTableList();
-	void addRef() { refCount++; }
-	void unRef() { refCount--; if (refCount == 0) delete this; }
-	WPXTable * operator[](size_t i) { return m_tableList[i]; }
-	void add(WPXTable *table) { m_tableList.push_back(table); }
-	size_t size() const { return m_tableList.size(); }
+
+	WPXTable * operator[](size_t i) { return (*m_tableList)[i]; }
+	void add(WPXTable *table) { m_tableList->push_back(table); }
 
 private:
-	vector<WPXTable *> m_tableList; 
-	int refCount;
+	void release(); 
+	void acquire(int *refCount, std::vector<WPXTable *> *tableList);
+	int * getRef() const { return m_refCount; }
+	std::vector<WPXTable *> * get() const { return m_tableList; }
+
+	std::vector<WPXTable *> *m_tableList; 
+	int *m_refCount;
 };
 #endif /* _WPXTABLE_H */
